@@ -241,7 +241,7 @@
         ;; same
         node-ttl-default (secs 0)
         node-purge-ttl-default (secs 0)
-        report-ttl-default (days 7)
+        report-ttl-default (days 14)
         parsed-commandproc (update-in command-processing [:dlo-compression-threshold] #(or (maybe-parse-period %) dlo-compression-default))
         parsed-database (-> database
                             (update-in [:gc-interval] #(or (maybe-minutes %) gc-interval-default))
@@ -361,6 +361,8 @@
         vardir                                     (validate-vardir (:vardir global))
         update-server                              (:update-server global "http://updates.puppetlabs.com/check-for-updates")
         resource-query-limit                       (get global :resource-query-limit 20000)
+        ;; TODO: revisit the choice of 20000 as a default value for event queries
+        event-query-limit                          (get global :event-query-limit 20000)
         db                                         (pl-jdbc/pooled-datasource database)
         gc-interval                                (get database :gc-interval)
         node-ttl                                   (get database :node-ttl)
@@ -373,6 +375,7 @@
                                                     :command-mq           {:connection-string mq-addr
                                                                            :endpoint          mq-endpoint}
                                                     :resource-query-limit resource-query-limit
+                                                    :event-query-limit event-query-limit
                                                     :update-server        update-server}]
 
 
