@@ -1,5 +1,6 @@
 (ns com.puppetlabs.puppetdb.http.experimental
   (:use [com.puppetlabs.puppetdb.http.experimental.catalog :only (catalog-app)]
+        [com.puppetlabs.puppetdb.http.experimental.planetarium-catalog :only (planetarium-catalog-app)]
         [com.puppetlabs.puppetdb.http.experimental.population :only (population-app)]
         [com.puppetlabs.puppetdb.http.experimental.event :only (events-app)]
         [com.puppetlabs.puppetdb.http.experimental.report :only (reports-app)]
@@ -10,6 +11,9 @@
    ["catalog" &]
    {:any catalog-app}
 
+   ["planetarium-catalog" &]
+   {:any planetarium-catalog-app}
+
    ["population" &]
    {:any population-app}
 
